pub trait FromPtr: Atomic {
// Required method
unsafe fn from_ptr<'a>(ptr: *mut Self::Type) -> &'a Self;
}Expand description
Creates a new atomic type from a pointer.
Required Methods
Sourceunsafe fn from_ptr<'a>(ptr: *mut Self::Type) -> &'a Self
unsafe fn from_ptr<'a>(ptr: *mut Self::Type) -> &'a Self
Creates a new atomic type from a pointer.
Safety
ptrmust be aligned toalign_of::<Self>()(note that on some platforms this can be bigger thanalign_of::<Self::Type>()).ptrmust be [valid] for both reads and writes for the whole lifetime'a.- You must adhere to the [Memory model for atomic accesses]. In particular, it is not allowed to mix atomic and non-atomic accesses, or atomic accesses of different sizes, without synchronization.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl FromPtr for Atomic<i8>
Available on (crate features atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.
impl FromPtr for Atomic<i8>
Available on (crate features
atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.Sourceimpl FromPtr for Atomic<i16>
Available on (crate features atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.
impl FromPtr for Atomic<i16>
Available on (crate features
atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.Sourceimpl FromPtr for Atomic<i32>
Available on (crate features atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.
impl FromPtr for Atomic<i32>
Available on (crate features
atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.Sourceimpl FromPtr for Atomic<i64>
Available on (crate features atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.
impl FromPtr for Atomic<i64>
Available on (crate features
atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.Sourceimpl FromPtr for Atomic<isize>
Available on (crate features atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.
impl FromPtr for Atomic<isize>
Available on (crate features
atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.Sourceimpl FromPtr for Atomic<u8>
Available on (crate features atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.
impl FromPtr for Atomic<u8>
Available on (crate features
atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.Sourceimpl FromPtr for Atomic<u16>
Available on (crate features atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.
impl FromPtr for Atomic<u16>
Available on (crate features
atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.Sourceimpl FromPtr for Atomic<u32>
Available on (crate features atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.
impl FromPtr for Atomic<u32>
Available on (crate features
atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.Sourceimpl FromPtr for Atomic<u64>
Available on (crate features atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.
impl FromPtr for Atomic<u64>
Available on (crate features
atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.Sourceimpl FromPtr for Atomic<usize>
Available on (crate features atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.
impl FromPtr for Atomic<usize>
Available on (crate features
atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.Sourceimpl<T> FromPtr for Atomic<*mut T>
Available on (crate features atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.
impl<T> FromPtr for Atomic<*mut T>
Available on (crate features
atomic_from_ptr or since_1_75_0) and non-crate feature loom_atomics only.